@@ -47,12 +47,13 @@ import tayra.filterblocks.pycode
 # Import escapefilter-plugins so that they can register themselves.
 import tayra.escfilters.common
 
-__version__ = '0.1dev'
+__version__ = '0.2dev'
 
 EP_TTLGROUP = 'tayra.plugins'
 EP_TTLNAME  = 'ITTLPlugin'
 DEFAULT_ENCODING = 'utf-8'
 ESCFILTER_RE = re.compile( r'([a-zA-Z0-9_-]+)(\.[a-zA-Z0-9_.-]+)*,' )
+DEVMOD = False
 
 defaultconfig = ConfigDict()
 defaultconfig.__doc__ = """Configuration settings for tayra template engine."""
@@ -88,14 +89,14 @@ defaultconfig['yacctab']    = {
 defaultconfig['strict_undefined']    = {
     'default' : False,
     'types'   : (bool,),
-    'help'    : "Boolean to raise exception for un-defined context variables. "
+    'help'    : "Boolean to raise exception for undefined context variables. "
                 "If set to false, undefined variables will be silently "
                 "digested as 'None' string. "
 }
 defaultconfig['directories']             = {
     'default' : '.',
     'types'   : ('csv', list),
-    'help'    : "Comma seperated list of directory path to look for a "
+    'help'    : "Comma separated list of directory path to look for a "
                 "template file. Default will be current-directory."
 }
 defaultconfig['module_directory']        = {
@@ -107,18 +108,18 @@ defaultconfig['module_directory']        = {
 defaultconfig['escape_filters']          = {
     'default' : '',
     'types'   : ('csv', list),
-    'help'    : "Comma seperated list of default escape filters to be applied "
+    'help'    : "Comma separated list of default escape filters to be applied "
                 "during expression substitution."
 }
 defaultconfig['input_encoding']          = {
     'default' : 'utf-8',
     'types'   : (str,),
-    'help'    : "Default input endcoding for .ttl file."
+    'help'    : "Default input encoding for .ttl file."
 }
 defaultconfig['usetagplugins']           = {
     'default' : ['html5', 'html5.forms'],
     'types'   : ('csv', list),
-    'help'    : "Comma seperated list of tag plugin namespaces to use. Only "
+    'help'    : "Comma separated list of tag plugin namespaces to use. Only "
                 "plugins that are registered under the requested namespace will "
                 "be used to generate the html."
 }
@@ -131,7 +132,7 @@ defaultconfig['uglyhtml']                = {
 defaultconfig['plugin_packages']         = {
     'default' : '',
     'types'   : ('csv', list),
-    'help'    : "Comma seperated list of plugin packages that needs to be "
+    'help'    : "Comma separated list of plugin packages that needs to be "
                 "imported, before compiling template files."
 }
 defaultconfig['memcache']                = {
@@ -154,7 +155,11 @@ def normalizeconfig( config ):
     data types. It is assumed that all config parameters are atleast initialized
     with default value.
     """
-    config['devmod'] = asbool( config['devmod'] )
+    config_ = dict( defaultconfig.items() )
+    config_.update( config )
+    config = config_
+    config['devmod'] = asbool( config.get('devmod', DEVMOD) )
+    config['parse_optimize'] = asbool( config['parse_optimize'] )
     config['strict_undefined'] = asbool( config['strict_undefined'] )
     config['module_directory'] = config['module_directory'] or None
     config['uglyhtml'] = asbool( config['uglyhtml'] )
@@ -307,9 +312,12 @@ class Renderer( object ):
 
     """
     def __init__( self, ttlloc=None, ttltext=None, ttlconfig={} ):
-        ttlconfig = ttlconfig or deepcopy( dict(defaultconfig.items()) )
+        self.ttlconfig = dict( defaultconfig.items() )
+        self.ttlconfig.update( ttlconfig )
+        self.ttlconfig.setdefault( 'devmod', DEVMOD )
         # Initialize plugins
-        self.ttlconfig = initplugins( ttlconfig, force=ttlconfig['devmod'] )
+        self.ttlconfig = initplugins(
+                self.ttlconfig, force=self.ttlconfig['devmod'] )
         self.ttlloc, self.ttltext = ttlloc, ttltext
         self.ttlparser = TTLParser( ttlconfig=self.ttlconfig )
 
@@ -352,7 +360,6 @@ def ttl_cmdline( ttlloc, **kwargs ):
     ttlconfig = deepcopy( dict( defaultconfig.items() ))
     # directories, module_directory, devmod
     ttlconfig.update( kwargs )
-    ttlconfig.setdefault( 'module_directory', dirname( ttlloc ))
 
     # Parse command line arguments and configuration
     args = eval( ttlconfig.pop( 'args', '[]' ))
@@ -365,6 +372,7 @@ def ttl_cmdline( ttlloc, **kwargs ):
     encoding = ttlconfig['input_encoding']
 
     # Initialize plugins
+    ttlconfig.setdefault('devmod', DEVMOD)
     ttlconfig = initplugins( ttlconfig, force=ttlconfig['devmod'] )
 
     # Setup parser
@@ -394,7 +402,6 @@ def ttl_cmdline( ttlloc, **kwargs ):
         # Intermediate file should always be encoded in 'utf-8'
         codecs.open(pyfile, mode='w', encoding=DEFAULT_ENCODING).write(pytext)
 
-        ttlconfig.setdefault( 'memcache', True )
         r = Renderer( ttlloc=ttlloc, ttlconfig=ttlconfig )
         html = r( context=context )
         codecs.open( htmlfile, mode='w', encoding=encoding).write( html )
